@@ -12,6 +12,7 @@ my $rc;
 
 eval {
 ############################################################################################################
+
 $dri->add_registry('VNDS',{});
 $rc=$dri->target('VNDS')->new_current_profile('profile1','whois');
 die($rc) unless $rc->is_success();
@@ -53,6 +54,31 @@ $rc=$dri->target('NAME')->new_current_profile('profile1','whois');
 die($rc) unless $rc->is_success();
 display('sudoku.name',$dri);
 
+$dri->add_registry('LU',{});
+$rc=$dri->target('LU')->new_current_profile('profile1','whois');
+die($rc) unless $rc->is_success();
+display('restena.lu',$dri);
+
+$dri->add_registry('WS',{});
+$rc=$dri->target('WS')->new_current_profile('profile1','whois');
+die($rc) unless $rc->is_success();
+display('website.ws',$dri);
+
+$dri->add_registry('SE',{});
+$rc=$dri->target('SE')->new_current_profile('profile1','whois');
+die($rc) unless $rc->is_success();
+display('malmo.se',$dri);
+
+$dri->add_registry('CAT',{});
+$rc=$dri->target('CAT')->new_current_profile('profile1','whois');
+die($rc) unless $rc->is_success();
+display('madrid.cat',$dri);
+
+$dri->add_registry('AT',{});
+$rc=$dri->target('AT')->new_current_profile('profile1','whois');
+die($rc) unless $rc->is_success();
+display('stare.at',$dri);
+
 
 $dri->end();
 };
@@ -89,8 +115,8 @@ sub display
   {
    print $k.': '.($dri->get_info($k) || 'n/a')."\n";
   }
-  print 'status: '.join(' ',$dri->get_info('status')->list_status())."\n";
-  print 'ns: '.join(' ',$dri->get_info('ns')->get_names())."\n" if defined($dri->get_info('ns'));
+  print 'status: '.join(' ',$dri->get_info('status')->list_status())."\n" if defined($dri->get_info('status'));
+  print 'ns: '.$dri->get_info('ns')->as_string()."\n" if defined($dri->get_info('ns'));
  }
  my $cs=$dri->get_info('contact');
  if ($cs)
