@@ -1,7 +1,7 @@
 ## Domain Registry Interface, BookMyName Web Services Protocol
 ## As seen on http://api.doc.free.org/revendeur-de-nom-de-domaine
 ##
-## Copyright (c) 2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,16 +11,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::BookMyName::WS;
 
 use strict;
-use warnings;
 
 use base qw(Net::DRI::Protocol);
 use Net::DRI::Protocol::BookMyName::WS::Message;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,27 +69,31 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($c,$ctx,$rp)=@_;
- my $self=$c->SUPER::new($ctx);
+ my $c=shift;
+ my ($drd,$version,$extrah)=@_;
+
+ my $self=$c->SUPER::new(); ## we are now officially a Net::DRI::Protocol object
  $self->name('bookmyname_ws');
- $self->version('0.1');
- $self->factories('message',sub { my $m=Net::DRI::Protocol::BookMyName::WS::Message->new(); $m->version('0.1'); return $m; });
- $self->_load($rp);
+ $self->version($VERSION);
+
+ $self->capabilities({});
+
+ $self->factories({ message => sub { my $m=Net::DRI::Protocol::BookMyName::WS::Message->new(); $m->version($VERSION); return $m; },
+                  });
+
+ bless($self,$c); ## rebless
+
+ $self->_load($extrah);
  return $self;
 }
 
 sub _load
 {
- my ($self,$rp)=@_;
+ my ($self,$extrah)=@_;
  my @class=map { 'Net::DRI::Protocol::BookMyName::WS::'.$_ } (qw/Account Domain/);
- return $self->SUPER::_load(@class);
+ $self->SUPER::_load(@class);
 }
 
-sub transport_default
-{
- my ($self)=@_;
- return (has_login=>0,has_logout=>0,defer=>1);
-}
 
-####################################################################################################
+##########################################################################################################
 1;
