@@ -1,6 +1,6 @@
 ## Domain Registry Interface, BookMyName Web Services Message
 ##
-## Copyright (c) 2008-2010,2013-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,18 +10,23 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::BookMyName::WS::Message;
 
 use strict;
-use warnings;
 
+use Carp;
 use Net::DRI::Protocol::ResultStatus;
 
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version method params operation result retcode retval));
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -50,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,32 +71,21 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($class,$trid,$otype,$oaction)=@_;
+ my $class=shift;
  my $self={errcode => undef, errmsg => undef};
  bless($self,$class);
+ my ($trid,$otype,$oaction)=@_;
 
  $self->params([]); ## default
  return $self;
 }
 
-sub as_string
-{
- my ($self)=@_;
- my @p=@{$self->params()};
- my @pr;
- foreach my $i (0..$#p)
- {
-  push @pr,sprintf 'PARAM%d=%s',$i+1,$p[$i];
- }
- return sprintf "METHOD=%s\n%s\n",$self->method(),join("\n",@pr);
-}
-
+sub as_string { return; }
 sub add_session
 {
  my ($self,$sd)=@_;
  my $rp=$self->params();
  unshift(@$rp,$sd->{id},$sd->{pass});
- return;
 }
 
 sub parse
@@ -102,7 +96,6 @@ sub parse
  $self->result($res->{retfields}) if exists($res->{retfields});
  $self->retcode($res->{retcode}); ## integer
  $self->retval($res->{retval}); ## integer
- return;
 }
 
 ## See http://api.doc.free.org/revendeur-de-nom-de-domaine
@@ -111,12 +104,6 @@ our %CODES=(	domain_info => {	'-1,-1' => 2200,
 					'-1,-3' => 2003,
 					'0,0' => 2303,
 				},
-		domain_check => {	'-1,-1' => 2200,
-					'-1,-2' => 2303,
-					'-1,-3' => 2103,
-					'-1,-4' => 2303,
-					'-1,-5' => 2003,
-				},
 		account_list_domains =>	{
 					'-1,-1' => 2200,
 					},
@@ -129,9 +116,23 @@ sub result_status
  my $self=shift;
  my ($op,$rc,$rv)=($self->operation(),$self->retcode(),$self->retval());
  my $ok=$self->is_success();
+
  my $k=$rc.','.$rv;
- my $eppcode=(exists $CODES{$op} && ref $CODES{$op} eq 'HASH' && exists $CODES{$op}->{$k})? $CODES{$op}->{$k} : 'COMMAND_FAILED';
- return Net::DRI::Protocol::ResultStatus->new('bookmyname_ws',100*$rc+$rv,$ok ? 'COMMAND_SUCCESSFUL' : $eppcode,$ok,'retcode='.$rc.' retval='.$rv,'en');
+ my $eppcode=(exists($CODES{$op}) && (ref($CODES{$op}) eq 'HASH') && keys(%{$CODES{$op}}) && exists($CODES{$op}->{$k}))? $CODES{$op}->{$k}  : 'GENERIC_ERROR';
+ return Net::DRI::Protocol::ResultStatus->new('bookmyname_ws',100*$rc+$rv,$ok? 'COMMAND_SUCCESSFUL' : $eppcode,$ok,'retcode='.$rc.' retval='.$rv,'en');
+}
+
+####################################################################################################
+
+sub get_name_from_message
+{
+ my ($self)=@_;
+ my $c=$self->method();
+ my $rp=$self->params();
+
+ return 'domains' if ($c eq 'domain_list');
+ return $rp->[2] if ($c=~m/^domain/);
+ return 'session';
 }
 
 ####################################################################################################
