@@ -1,6 +1,6 @@
 ## Domain Registry Interface, DAS Message
 ##
-## Copyright (c) 2007-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,18 +10,25 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::DAS::Message;
 
 use strict;
-use warnings;
+
+use Encode ();
 
 use Net::DRI::Protocol::ResultStatus;
 use Net::DRI::Exception;
+use Net::DRI::Util;
 
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
-__PACKAGE__->mk_accessors(qw(version errcode errmsg errlang command command_param cltrid response));
+__PACKAGE__->mk_accessors(qw(version errcode errmsg errlang command command_param command_tld cltrid response));
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -51,7 +58,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,7 +74,10 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($class,$trid)=@_;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+ my $trid=shift;
+
  my $self={
            errcode => -1000,
 	   response => {},
@@ -92,36 +102,32 @@ sub result_status
         -6 => 2005, ## Invalid version => Parameter value syntax error
        );
  my $c=$self->errcode();
- my $rs=Net::DRI::Protocol::ResultStatus->new('das',$c,exists $C{$c} ? $C{$c} : 'COMMAND_FAILED',$self->is_success(),$self->errmsg(),$self->errlang(),undef);
+ my $rs=Net::DRI::Protocol::ResultStatus->new('das',$c,exists($C{$c})? $C{$c} : $Net::DRI::Protocol::ResultStatus::EPP_CODES{GENERIC_ERROR},$self->is_success(),$self->errmsg(),$self->errlang(),undef);
  $rs->_set_trid([ $self->cltrid(),undef ]);
  return $rs;
 }
 
 sub as_string
 {
- my ($self)=@_;
+ my ($self,$to)=@_;
  my $s=sprintf("%s %s %s\x0d\x0a",$self->command(),$self->version(),$self->command_param());
- return $s;
+ return Encode::encode('ascii',$s);
 }
 
 sub parse
 {
  my ($self,$dc,$rinfo)=@_;
  my @d=$dc->as_array();
- my $rc;
- my @tmp=grep { /^%% RC\s*=\s*\S+/ } @d;
- if (@tmp)
- {
-  ($rc)=($tmp[0]=~m/^%% RC\s*=\s*(\S+)\s*$/);
-  $self->errcode($rc);
- }
+ my @tmp=grep { /^%% RC = \S+/ } @d;
+ Net::DRI::Exception->die(0,'protocol/DAS',1,'Unsuccessfull parse, no RC in server reply') unless (@tmp==1);
+ my ($rc)=($tmp[0]=~m/^%% RC = (\S+)\s*$/);
+ $self->errcode($rc);
 
- if ((defined $rc && $rc==0) || grep { /^Status: /} @d) ## success
+ if ($rc==0) ## success
  {
-  $self->errcode(0);
   my %info=map { m/^(\S+):\s+(.*\S)\s*$/; $1 => $2 } grep { /^\S+: / } @d;
-  Net::DRI::Exception->die(0,'protocol/DAS',1,'Unsuccessfull parse, missing key Domain') unless exists $info{Domain};
-  Net::DRI::Exception->die(0,'protocol/DAS',1,'Unsuccessfull parse, missing key Status') unless exists $info{Status};
+  Net::DRI::Exception->die(0,'protocol/DAS',1,'Unsuccessfull parse, missing key Domain') unless (exists($info{Domain}));
+  Net::DRI::Exception->die(0,'protocol/DAS',1,'Unsuccessfull parse, missing key Status') unless (exists($info{Status}));
   $self->response(\%info);
  } else
  {
@@ -129,8 +135,13 @@ sub parse
   my ($msg)=($d[-1]=~m/^%\s*(\S.+\S)\s*$/);
   $self->errmsg($msg);
  }
- return;
 }
 
-####################################################################################################
+sub get_name_from_message
+{
+ my ($self)=@_;
+ return lc($self->command_param().'.'.$self->command_tld());
+}
+
+########################################################################
 1;
