@@ -1,7 +1,6 @@
-## Domain Registry Interface, .ASIA EPP extensions
+## Domain Registry Interface, ASIA EPP extensions
 ##
-## Copyright (c) 2007-2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-##           (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,21 +10,25 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::ASIA;
 
 use strict;
-use warnings;
 
 use Net::DRI::Data::Contact::ASIA;
 use base qw/Net::DRI::Protocol::EPP/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::ASIA - .ASIA EPP extensions for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::ASIA - ASIA EPP extensions for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -50,8 +53,7 @@ Tonnerre Lombard E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>
+Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,22 +66,33 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({ asia => 'urn:afilias:params:xml:ns:asia-1.0',
-             ipr  => 'urn:afilias:params:xml:ns:ipr-1.1',
-             oxrs => 'urn:afilias:params:xml:ns:oxrs-1.1',
-           });
- $self->factories('contact',sub { return Net::DRI::Data::Contact::ASIA->new(@_); });
- $self->capabilities('domain_update','maintainer_url',['set']);
- $self->capabilities('domain_update','contact',['add','set','del']);
- $self->capabilities('domain_update','ipr',['set','del']);
- return;
-}
+ my $h=shift;
+ my $c=ref($h) || $h;
 
-sub default_extensions { return qw/GracePeriod Afilias::IPR ASIA::CED ASIA::Domain SecDNS/; }
+ my ($drd,$version,$extrah,$defproduct)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ if (exists($e{':full'})) ## useful shortcut, modeled after Perl itself
+ {
+  delete($e{':full'});
+  $e{'Net::DRI::Protocol::EPP::Extensions::GracePeriod'}=1;
+  $e{'Net::DRI::Protocol::EPP::Extensions::ASIA::IPR'}=1;
+  $e{'Net::DRI::Protocol::EPP::Extensions::ASIA::CED'}=1;
+ }
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ if (exists($e{'Net::DRI::Protocol::EPP::Extensions::ASIA::CED'}))
+ {
+  my $rfact=$self->factories();
+  $rfact->{contact}=sub { return Net::DRI::Data::Contact::ASIA->new(@_); };
+ }
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
