@@ -1,7 +1,7 @@
 ## Domain Registry Interface, ENUM.AT Options extension
 ## Contributed by Michael Braunoeder from ENUM.AT <michael.braunoeder@enum.at>
 ##
-## Copyright (c) 2006,2008,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,16 +11,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AT::IOptions;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
-use feature 'state';
+
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $NS='http://www.enum.at/rxsd/ienum43-options-1.0';
 
 =pod
 
@@ -50,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -76,28 +80,22 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
-sub setup
+sub capabilities_add
 {
- my ($class,$po,$version)=@_;
- state $ns = { 'ienum43' => 'http://www.enum.at/rxsd/ienum43-options-1.0',
-             };
- $po->ns($ns);
- return;
+ return { 'domain_update' => { 'options' => [ 'set'] }};
 }
 
-sub capabilities_add { return ('domain_update','options',['set']); }
-
 sub parse_options
 {
  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
 
- my $condata=$mes->get_extension('ienum43','options');
+ my $condata=$mes->get_content('options',$NS,1);
  return unless $condata;
 
  my @options;
 
- foreach my $el ($condata->getElementsByTagNameNS($mes->ns('ienum43'),'naptr-application'))
+ foreach my $el ($condata->getElementsByTagNameNS($NS,'naptr-application'))
  {
   my %opts;
   my $c=$el->getFirstChild();
@@ -109,12 +107,12 @@ sub parse_options
  }
 
  $rinfo->{domain}->{$oname}->{options}=\@options;
- return;
 }
 
 sub set_options
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  my $roptions=$rd->set('options');
  return unless (defined($roptions) && (ref($roptions) eq 'HASH') && keys(%$roptions));
@@ -127,10 +125,10 @@ sub set_options
   $options{$d}=$roptions->{'naptr_application_'.$d};
  }
 
- return unless keys %options;
+ return unless keys(%options);
 
- $epp->message()->command_extension('ienum43',['update', ['options', ['naptr-application', \%options]]]);
- return;
+ my $eid=$mes->command_extension_register('ienum43:update','xmlns:ienum43="'.$NS.'" xsi:schemaLocation="'.$NS.' ienum43-options-1.0.xsd"');
+ $mes->command_extension($eid,[['ienum43:options',['ienum43:naptr-application',\%options]]]);
 }
 
 ####################################################################################################
