@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .AU Domain EPP extension commands
 ##
-## Copyright (c) 2007,2008,2013 Distribute.IT Pty Ltd, www.distributeit.com.au, Rony Meyer <perl@spot-light.ch>. All rights reserved.
-## Copyright (c) 2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008 Distribute.IT Pty Ltd, www.distributeit.com.au, Rony Meyer <perl@spot-light.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,15 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AU::Domain;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,8 +51,7 @@ Rony Meyer, E<lt>perl@spot-light.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>, Rony Meyer <perl@spot-light.ch>.
-Copyright (c) 2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007,2008 Distribute.IT Pty Ltd, E<lt>http://www.distributeit.com.auE<gt>, Rony Meyer <perl@spot-light.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,11 +76,25 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
+sub capabilities_add
+{
+ return { 'domain_update' => { 'maintainer_url' => [ 'set' ]} };
+}
+
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ 
+ my @ns=@{$mes->ns()->{'auext'}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:auext="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('eligibility attribute is mandatory, as ref hash') 
          unless (exists($rd->{eligibility}) && (ref($rd->{eligibility}) eq 'HASH'));
@@ -104,8 +120,12 @@ sub create
  }
  push @n,['auext:policyReason',$rd->{eligibility}->{policyReason}];
 
- $epp->message()->command_extension('auext', ['extensionAU', ['create', @n]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'auext:extensionAU');
+
+ my @nn;
+ push @nn, ['auext:create',@n];
+
+ $mes->command_extension($eid,\@nn);
 }
 
 
@@ -115,7 +135,8 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('auextnew','infData');
+ # my $infdata=$mes->get_content('extensionAU',$mes->ns('auext'),1);
+ my $infdata=$mes->get_content('infData',$mes->ns('auextnew'),1);
  return unless $infdata;
 
  my %ens;
@@ -162,7 +183,6 @@ sub info_parse
  } continue { $c=$c->getNextSibling(); }
 
  $rinfo->{domain}->{$oname}->{eligibility}=\%ens;
- return;
 }
 ####################################################################################################
 1;
