@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT Domain EPP extension commands
 ##
-## Copyright (c) 2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -23,7 +23,7 @@ use Email::Valid;
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -53,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2007 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -101,7 +101,7 @@ sub add_name_variant
 
  foreach my $n ((ref($d) eq 'ARRAY')? @{$d} : ($d))
  {
-  Net::DRI::Exception::usererr_invalid_parameters("$n in name_variant attribute must be an XML token between 1 & 255 chars in length") unless Net::DRI::Util::xml_is_token($n,1,255);
+  Net::DRI::Exception::usererr_invalid_parameters($n.' in name_variant attribute must be an XML token between 1 & 255 chars in length') unless Net::DRI::Util::xml_is_token($n,1,255);
   push @n,['dx:nameVariant',$n];
  }
 
@@ -111,14 +111,14 @@ sub add_name_variant
 sub add_lang
 {
  my ($d)=@_;
- Net::DRI::Exception::usererr_invalid_parameters("lang attribute must be an XML language") unless (($d eq '') || Net::DRI::Util::xml_is_language($d));
+ Net::DRI::Exception::usererr_invalid_parameters('lang attribute must be an XML language') unless (($d eq '') || Net::DRI::Util::xml_is_language($d));
  return ['dx:language',$d];
 }
 
 sub add_maintainer
 {
  my ($d)=@_;
- Net::DRI::Exception::usererr_invalid_parameters("maintainer attribute must be an XML token not more than 128 chars long") unless Net::DRI::Util::xml_is_token($d,undef,128);
+ Net::DRI::Exception::usererr_invalid_parameters('maintainer attribute must be an XML token not more than 128 chars long') unless Net::DRI::Util::xml_is_token($d,undef,128);
  return ['dx:maintainer',$d];
 }
 
@@ -139,7 +139,7 @@ sub add_puntcat_extension
  {
   push @n,add_name_variant($rd->{name_variant});
  }
- 
+
  push @n,add_lang($rd->{lang})             if (exists($rd->{lang}) && defined($rd->{lang}));
  push @n,add_maintainer($rd->{maintainer}) if (exists($rd->{maintainer}) && defined($rd->{maintainer}));
 
@@ -203,13 +203,12 @@ sub update
 {
  my ($epp,$domain,$todo)=@_;
  my $mes=$epp->message();
- 
  my (@tmp,@n);
 
  if ($todo->types('name_variant'))
  {
   Net::DRI::Exception->die(0,'protocol/EPP',11,'Only name_variant add/del available for domain') if grep { ! /^(?:add|del)$/ } $todo->types('name_variant');
- 
+
   @tmp=add_name_variant($todo->add('name_variant'));
   push @n,['dx:add',@tmp] if @tmp;
   @tmp=add_name_variant($todo->del('name_variant'));
@@ -233,7 +232,6 @@ sub update
   Net::DRI::Exception->die(0,'protocol/EPP',11,'Only intended_use set available for domain') if grep { $_ ne 'set' } $todo->types('intended_use');
   push @tmp,add_intended_use($todo->set('intended_use'));
  }
- 
 
  push @n,['dx:chg',@tmp] if @tmp;
 
