@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CentralNic EPP extensions
 ## (http://labs.centralnic.com/epp/ext/)
 ##
-## Copyright (c) 2007-2011,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,15 +11,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CentralNic;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -62,18 +66,23 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({ttl => 'urn:centralnic:params:xml:ns:ttl-1.0',
-            wf  => 'urn:centralnic:params:xml:ns:wf-1.0',
-          });
- $self->capabilities('domain_update','ttl',['set']);
- $self->capabilities('domain_update','web_forwarding',['set']);
- return;
-}
+ my $h=shift;
+ my $c=ref($h) || $h;
 
-sub default_extensions { return qw/CentralNic::TTL CentralNic::WebForwarding CentralNic::Release CentralNic::Pricing SecDNS VeriSign::Sync/; }
+ my ($drd,$version,$extrah,$defproduct)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::CentralNic::TTL'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::CentralNic::WebForwarding'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::CentralNic::Release'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
