@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .NAME EPP extensions
 ##
-## Copyright (c) 2007-2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-##           (c) 2010,2012 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,17 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::NAME;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
 use Net::DRI::Protocol::EPP::Extensions::NAME::EmailFwd;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -51,8 +54,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2012 Patrick Mevzek <netdri@dotandco.com>
+Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,15 +68,24 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({ emailFwd => ['http://www.nic.name/epp/emailFwd-1.0','emailFwd-1.0.xsd'] });
- $self->capabilities('emailfwd_update','info',['set']);
- return;
-}
+ my $c=shift;
+ my ($drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
 
-sub default_extensions { return qw/NAME::EmailFwd VeriSign::IDNLanguage GracePeriod SecDNS/; }
+ $e{'Net::DRI::Protocol::EPP::Extensions::NAME::EmailFwd'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ foreach my $w ('emailFwd')
+ {
+  $self->{ns}->{$w}=['http://www.nic.name/epp/'.$w.'-1.0',$w.'-1.0.xsd'];
+ }
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
