@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EPP Email forwarding extension commands
 ## (based on .NAME Technical Accreditation Guide v3.03)
 ##
-## Copyright (c) 2007,2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
+## Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,12 +11,14 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::NAME::EmailFwd;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
@@ -24,6 +26,8 @@ use Net::DRI::Data::Contact;
 use Net::DRI::Data::ContactSet;
 use DateTime::Format::ISO8601;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -53,7 +57,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -83,11 +87,15 @@ sub register_commands
  return { 'emailfwd' => \%tmp1 };
 }
 
+sub capabilities_add
+{
+ return { 'emailfwd_update' => { 'info' => ['set'] } };
+}
+
 sub ns
 {
  my ($mes)=@_;
- my $ns=$mes->ns('emailFwd');
- return defined($ns)? $ns : 'http://www.nic.name/epp/emailFwd-1.0';
+ return (exists($mes->ns->{emailFwd}))? $mes->ns->{emailFwd}->[0] : 'http://www.nic.name/epp/emailFwd-1.0';
 }
 
 sub build_command
@@ -103,9 +111,8 @@ sub build_command
 
  Net::DRI::Exception->die(1,'protocol/EPP',2,'emailFwd name needed') unless (defined($info->{name}));
 
- my @ns=$msg->nsattrs('emailFwd');
- @ns=qw(http://www.nic.name/epp/emailFwd-1.0 http://www.nic.name/epp/emailFwd-1.0 emailFwd-1.0.xsd) unless @ns;
- $msg->command([$command,'emailFwd:'.$command,sprintf('xmlns:emailFwd="%s" xsi:schemaLocation="%s %s"',@ns)]);
+ my @ns=exists($msg->ns->{emailFwd})? @{$msg->ns->{emailFwd}} : ('http://www.nic.name/epp/emailFwd-1.0','emailFwd-1.0.xsd');
+ $msg->command([$command,'emailFwd:'.$command,sprintf('xmlns:emailFwd="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1])]);
 
  # @ret = map { ['emailFwd:' . $_, $info->{$_}] } keys(%{$info});
  push(@ret, ['emailFwd:name', $info->{name}]) if (defined($info->{name}));
@@ -115,12 +122,12 @@ sub build_command
  push(@ret, ['emailFwd:period', { unit => 'y' },
   	$info->{period}->in_units('years')]) if (defined($info->{period}));
  push(@ret, ['emailFwd:registrant', $info->{registrant}]) if (defined($info->{registrant}));
- foreach my $type (sort { $a cmp $b } keys %$contacts)
+ foreach my $type (keys %{$contacts})
  {
   push(@ret, ['emailFwd:contact', {type => $type}, $contacts->{$type}]);
  }
 
- foreach my $auth (sort { $a cmp $b } keys %$authid)
+ foreach my $auth (keys %{$authid})
  {
   push(@auth, ['emailFwd:' . $auth, $authid->{$auth}]);
  }
@@ -139,7 +146,6 @@ sub check
  my $mes=$epp->message();
  my @d=build_command($epp,$mes,'check', { name => $info });
  $mes->command_body(\@d);
- return;
 }
 
 sub check_parse
@@ -148,10 +154,10 @@ sub check_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $ns=ns('emailFwd');
- my $chkdata=$mes->get_response($ns,'chkData');
+ my $ns=$mes->ns('emailFwd');
+ my $chkdata=$mes->get_content('chkData',$ns);
  return unless $chkdata;
- foreach my $cd ($chkdata->getElementsByTagNameNS($ns,'cd'))
+ foreach my $cd ($chkdata->getElementsByTagNameNS($mes->ns('emailFwd'),'cd'))
  {
   my $c = $cd->getFirstChild();
   my $fwd;
@@ -169,7 +175,6 @@ sub check_parse
    }
   } continue { $c = $c->getNextSibling(); }
  }
- return;
 }
 
 sub info
@@ -178,7 +183,6 @@ sub info
  my $mes = $epp->message();
  my @d = build_command($epp,$mes,'info',{ name => $mail });
  $mes->command_body(\@d);
- return;
 }
 
 sub info_parse
@@ -187,11 +191,11 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_response(ns($mes),'infData');
+ my $infdata=$mes->get_content('infData',ns($mes));
  return unless $infdata;
 
  my $nm;
- my $cs = Net::DRI::Data::ContactSet->new();
+ my $cs = new Net::DRI::Data::ContactSet;
  my $info = {};
  my $ginfo = {};
 
@@ -216,13 +220,13 @@ sub info_parse
   }
   elsif (grep { $_ eq $name } qw/crDate upDate trDate exDate/)
   {
-   $ginfo->{$name} = DateTime::Format::ISO8601()->new()->
+   $ginfo->{$name} = (new DateTime::Format::ISO8601())->
    	parse_datetime($c->getFirstChild()->getData());
   }
   elsif (grep { $_ eq $name } qw/registrant contact/)
   {
    my $type = $c->getAttribute('type') || 'registrant';
-   $cs->add(Net::DRI::Data::Contact()->new()->
+   $cs->add((new Net::DRI::Data::Contact())->
    	srid($c->getFirstChild()->getData()), $type);
   }
   elsif ($name eq 'authInfo')
@@ -239,7 +243,6 @@ sub info_parse
  $ginfo->{action} = 'info';
  $ginfo->{self} = $info;
  $rinfo->{emailFwd}->{$nm} = $ginfo;
- return;
 }
 
 ############ Transform commands
@@ -252,16 +255,14 @@ sub create
  $info->{name} = $mail;
  @d = build_command($epp,$mes,'create',$info);
  $mes->command_body(\@d);
- return;
 }
 
-sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub delete
 {
  my ($epp,$mail)=@_;
  my $mes=$epp->message();
  my @d=build_command($epp,$mes,'delete',{ name => $mail });
  $mes->command_body(\@d);
- return;
 }
 
 sub update
@@ -269,7 +270,7 @@ sub update
  my ($epp,$hosts,$todo)=@_;
  my $mes=$epp->message();
 
- Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Changes object') unless Net::DRI::Util::isa_changes($todo);
+ Net::DRI::Exception::usererr_invalid_parameters($todo." must be a Net::DRI::Data::Changes object") unless ($todo && UNIVERSAL::isa($todo,'Net::DRI::Data::Changes'));
 
  if ((grep { ! /^(?:ns)$/ } $todo->types()) || (grep { ! /^(?:set)$/ } $todo->types('ns') ))
  {
@@ -280,7 +281,6 @@ sub update
  my @d=build_command($epp,$mes,'update',$hosts);
  push @d,add_nsname($ns);
  $mes->command_body(\@d);
- return;
 }
 
 sub renew
@@ -299,7 +299,6 @@ sub renew
 
  my @d = build_command($epp,$mes,'renew',$info);
  $mes->command_body(\@d);
- return;
 }
 
 ####################################################################################################
