@@ -1,8 +1,7 @@
 ## Domain Registry Interface, .UK EPP extensions
 ## As seen on http://www.nominet.org.uk/registrars/systems/epp/ and http://www.nominet.org.uk/digitalAssets/16844_EPP_Mapping.pdf
 ##
-## Copyright (c) 2008,2009,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
-##           (c) 2013 Michael Holloway <michael@thedarkwinter.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -12,17 +11,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::Nominet;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+use Net::DRI::Protocol::EPP::Message;
 use Net::DRI::Data::Contact::Nominet;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -51,8 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2018 Patrick Mevzek <netdri@dotandco.com>.
-          (c) 2013 Michael Holloway <michael@thedarkwinter.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,20 +69,37 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- my @extNS=qw/contact-nom-ext-1.0 domain-nom-ext-1.2 std-contact-id-1.0 std-fork-1.0 std-handshake-1.0 std-list-1.0 std-locks-1.0 std-notifications-1.2 std-release-1.0 std-unrenew-1.0 std-warning-1.1 nom-abuse-feed-1.0/;
- foreach my $ns (@extNS) { $self->ns({ (split(/-([^-]+)$/,$ns))[0] => 'http://www.nominet.org.uk/epp/xml/'.$ns }); }
- foreach my $o (qw/first-bill recur-bill auto-bill next-bill notes reseller auto-period next-period renew-not-required/) { $self->capabilities('domain_update',$o,['set']); }
- $self->factories('contact',sub { return Net::DRI::Data::Contact::Nominet->new(); });
+ my $c=shift;
+ my ($drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ my @c=map { 'Net::DRI::Protocol::EPP::Extensions::Nominet::'.$_ } qw/Domain Contact Host Account/;
+ push @c,'Session';
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)],\@c); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ foreach my $w (qw/domain contact ns account notifications/)
+ {
+  $self->{ns}->{$w}=['http://www.nominet.org.uk/epp/xml/nom-'.$w.'-1.0','nom-'.$w.'-1.0.xsd'];
+ }
+
+ my $rcapa=$self->capabilities();
+ delete($rcapa->{contact_update}->{status});
+ delete($rcapa->{domain_update}->{status});
+ $rcapa->{host_update}={ ip => ['set'], name => ['set'] };
+
+ my $rfact=$self->factories();
+ $rfact->{contact}=sub { return Net::DRI::Data::Contact::Nominet->new()->srid('ABCD') };
+ $rfact->{message}=sub { my $m=Net::DRI::Protocol::EPP::Message->new(@_); $m->ns($self->{ns}); $m->version($version); return $m;}; ## needed for change of XML NS
+
  $self->default_parameters({domain_create => { auth => { pw => '' } } }); ## domain:authInfo is not used by Nominet
- return;
+
+ bless($self,$c); ## rebless
+ return $self;
 }
 
-sub core_contact_types { return (); }
-sub default_extensions { return qw/Nominet::Session Nominet::Message Nominet::Domain Nominet::Contact Nominet::Notifications/; }
-
+sub core_contact_types { return ('admin','billing'); } ## not really used
 
 ####################################################################################################
 1;
