@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .UK EPP Host commands
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::Nominet::Host;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
+use Net::DRI::Data::Hosts;
+
+use DateTime::Format::ISO8601;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -48,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -76,11 +83,12 @@ sub register_commands
 sub build_command
 {
  my ($msg,$command,$hostname)=@_;
- my $roid=(Net::DRI::Util::isa_hosts($hostname))? $hostname->get_details(1)->[-1]->{roid} : $hostname;
- Net::DRI::Exception->die(1,'protocol/EPP',2,'Roid of NS object needed') unless (defined($roid) && $roid && !ref($roid));
- Net::DRI::Exception->die(1,'protocol/EPP',2,'Invalid ROID: '.$roid) unless ($roid=~m/^NS\d+(?:-UK)?$/);
+ my $roid=UNIVERSAL::isa($hostname,'Net::DRI::Data::Hosts')? $hostname->roid() : $hostname;
+ Net::DRI::Exception->die(1,'protocol/EPP',2,'Roid of NS object needed') unless defined($roid) && $roid;
+ Net::DRI::Exception->die(1,'protocol/EPP',2,'Host name needed') unless ($roid=~m/^NS\d+(?:-UK)?$/);
 
- $msg->command([$command,'ns:'.$command,sprintf('xmlns:ns="%s" xsi:schemaLocation="%s %s"',$msg->nsattrs('ns'))]);
+ my @ns=@{$msg->ns->{ns}};
+ $msg->command([$command,'ns:'.$command,sprintf('xmlns:ns="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1])]);
  return (['ns:roid',$roid]);
 }
 
@@ -93,7 +101,6 @@ sub info
  my $mes=$epp->message();
  my @d=build_command($mes,'info',$ns);
  $mes->command_body(\@d);
- return;
 }
 
 sub info_parse
@@ -101,51 +108,55 @@ sub info_parse
  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
  return unless $mes->is_success();
- my $infdata=$mes->get_response('ns','infData');
- return unless defined $infdata;
+
+ my $infdata=$mes->get_content('infData',$mes->ns('ns'));
+ return unless $infdata;
  parse_infdata($po,$mes,$infdata,$oname,$rinfo);
- return;
 }
 
 sub parse_infdata
 {
  my ($po,$mes,$infdata,$oname,$rinfo)=@_;
  my ($hostname,@ip4,@ip6);
+ my $pd=DateTime::Format::ISO8601->new();
+ my $c=$infdata->getFirstChild();
  my %i;
-
- foreach my $el (Net::DRI::Util::xml_list_children($infdata))
+ while ($c)
  {
-  my ($name,$c)=@$el;
+  next unless ($c->nodeType() == 1); ## only for element nodes
+  my $name=$c->localname() || $c->nodeName();
+  next unless $name;
+
   if ($name eq 'roid')
   {
-   $oname=$c->textContent();
+   $oname=$c->getFirstChild()->getData();
    $i{action}='info';
    $i{exist}=1;
    $i{roid}=$oname;
   } elsif ($name eq 'name')
   {
-   $hostname=lc($c->textContent());
+   $hostname=lc($c->getFirstChild()->getData());
    $i{name}=$hostname;
   } elsif ($name=~m/^(clID|crID|upID)$/)
   {
-   $i{$1}=$c->textContent();
+   $i{$1}=$c->getFirstChild()->getData();
   } elsif ($name=~m/^(crDate|upDate)$/)
   {
-   $i{$1}=$po->parse_iso8601($c->textContent());
+   $i{$1}=$pd->parse_datetime($c->getFirstChild()->getData());
   } elsif ($name eq 'addr')
   {
-   my $ip=$c->textContent();
+   my $ip=$c->getFirstChild()->getData();
    my $ipv=$c->getAttribute('ip');
    push @ip4,$ip if ($ipv eq 'v4');
    push @ip6,$ip if ($ipv eq 'v6');
   }
- }
+ } continue { $c=$c->getNextSibling(); }
 
  while(my ($k,$v)=each(%i))
  {
   $rinfo->{host}->{$hostname}->{$k}=$rinfo->{host}->{$oname}->{$k}=$v;
  }
- $rinfo->{host}->{$hostname}->{self}=$rinfo->{host}->{$oname}->{self}=$po->create_local_object('hosts',$hostname,\@ip4,\@ip6,1,{roid=>$oname});
+ $rinfo->{host}->{$hostname}->{self}=$rinfo->{host}->{$oname}->{self}=Net::DRI::Data::Hosts->new($hostname,\@ip4,\@ip6,1)->roid($oname);
  return $rinfo->{host}->{$hostname}->{self};
 }
 
@@ -156,7 +167,7 @@ sub update
  my ($epp,$ns,$todo)=@_;
  my $mes=$epp->message();
 
- Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Changes object') unless Net::DRI::Util::isa_changes($todo);
+ Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Changes object') unless ($todo && UNIVERSAL::isa($todo,'Net::DRI::Data::Changes'));
  if ((grep { ! /^(?:set)$/ } $todo->types('ip')) ||
      (grep { ! /^(?:set)$/ } $todo->types('name'))
     )
@@ -176,14 +187,13 @@ sub update
 
  if (defined($ipset) && $ipset)
  {
-  Net::DRI::Exception::usererr_invalid_parameters($ipset.' must be a Net::DRI::Data::Hosts object') unless Net::DRI::Util::isa_hosts($ipset);
-  my ($name,$r4,$r6)=$ipset->get_details(1);
+  Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Hosts object') unless ($todo && UNIVERSAL::isa($todo,'Net::DRI::Data::Hosts'));
+  my ($name,$r4,$r6)=$ns->get_details(1);
   push @d,['ns:addr',{ip=>'v4'},$r4->[0]] if @$r4; ## it seems only one IP is allowed
   push @d,['ns:addr',{ip=>'v6'},$r6->[0]] if @$r6; ## ditto
  }
 
  $mes->command_body(\@d);
- return;
 }
 
 ####################################################################################################
