@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .US EPP extensions (draft-liu-epp-usTLD-00)
 ##
-## Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::US;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+use Net::DRI::Data::Contact::US;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -47,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -60,14 +66,24 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- return;
-}
+ my $h=shift;
+ my $c=ref($h) || $h;
 
-sub default_extensions { return qw/US::Contact/; }
+ my ($drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::US::Contact'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ my $rfact=$self->factories();
+ $rfact->{contact}=sub { return Net::DRI::Data::Contact::US->new(); };
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
