@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Gandi Web Services Connection handling
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Gandi::WS::Connection;
 
 use strict;
-use warnings;
-
 use XMLRPC::Lite; ## needed to have XMLRPC::Data
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -47,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -59,11 +62,13 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 ####################################################################################################
 
 sub login
 {
- my ($class,$cm,$id,$pass,$cltrid)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my ($cm,$id,$pass,$cltrid)=@_;
  my $mes=$cm->();
  $mes->method('login');
  $mes->params([$id,$pass,XMLRPC::Data->type('boolean')->value(0)]);
@@ -72,22 +77,18 @@ sub login
 
 sub parse_login
 {
- my ($class,$mes)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my $mes=shift;
  $mes->errmsg($mes->is_success()? 'Login OK' : 'Login failed') unless $mes->errmsg();
  return $mes->result_status();
 }
 
 sub extract_session
 {
- my ($class,$mes)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my $mes=shift;
  return { id => $mes->value() };
 }
 
-sub transport_default
-{
- my ($self,$tname)=@_;
- return (defer => 1, has_login => 1, has_logout => 0);
-}
-
 ####################################################################################################
 1;
