@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Gandi Web Services Message
 ##
-## Copyright (c) 2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,18 +10,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Gandi::WS::Message;
 
 use strict;
-use warnings;
 
 use Net::DRI::Protocol::ResultStatus;
 
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version method params result errcode errmsg));
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -50,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,32 +70,21 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($class,$trid,$otype,$oaction)=@_;
+ my $class=shift;
  my $self={errcode => undef, errmsg => undef};
  bless($self,$class);
+ my ($trid,$otype,$oaction)=@_;
 
  $self->params([]); ## empty default
  return $self;
 }
 
-sub as_string
-{
- my ($self)=@_;
- my @p=@{$self->params()};
- my @pr;
- foreach my $i (0..$#p)
- {
-  push @pr,sprintf 'PARAM%d=%s',$i+1,$p[$i];
- }
- return sprintf "METHOD=%s\n%s\n",$self->method(),join("\n",@pr);
-}
-
+sub as_string { return; }
 sub add_session
 {
  my ($self,$sd)=@_;
  my $rp=$self->params();
  unshift(@$rp,$sd->{id});
- return;
 }
 
 sub parse
@@ -109,7 +102,6 @@ sub parse
   $self->errcode(0); ## probably success
   $self->errmsg('No status/msg given');
  }
- return;
 }
 
 sub is_success { return (shift->errcode()==0)? 1 : 0; }
@@ -124,7 +116,7 @@ sub result_status
 
  return Net::DRI::Protocol::ResultStatus->new('gandi_ws',$code,'COMMAND_SUCCESSFUL',1,$msg,'en') if $ok;
 
- my $eppcode='COMMAND_FAILED';
+ my $eppcode='GENERIC_ERROR';
  if ($code=~m/^1/)
  {
   $eppcode=2400; ## Command failed
@@ -145,7 +137,7 @@ sub result_status
   } elsif ($code=~m/30$/)
   {
    $eppcode=2004;
-  } elsif ($code=~m/3[14]$/)
+   } elsif ($code=~m/3[14]$/)
   {
    $eppcode=2306;
   } elsif ($code=~m/32$/)
@@ -172,5 +164,18 @@ sub result_status
  return Net::DRI::Protocol::ResultStatus->new('gandi_ws',$code,$eppcode,0,$msg,'en');
 }
 
+####################################################################################################
+
+sub get_name_from_message
+{
+ my ($self)=@_;
+ my $c=$self->method();
+ my $rp=$self->params();
+
+ return 'domains' if ($c eq 'domain_list');
+ return $rp->[1] if ($c=~m/^domain/);
+ return 'session';
+}
+
 ####################################################################################################
 1;
