@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OVH Web Services Connection handling
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,12 +10,16 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::OVH::WS::Connection;
 
 use strict;
-use warnings;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -45,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -57,27 +61,31 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 ####################################################################################################
 
 sub login
 {
- my ($class,$cm,$id,$pass,$cltrid)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my ($cm,$id,$pass,$cltrid)=@_;
  my $mes=$cm->();
  $mes->method('login');
- $mes->params([$id,$pass,'fr',0]);
+ $mes->params({nic => $id,password => $pass});
  return $mes;
 }
 
 sub parse_login
 {
- my ($class,$mes)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my $mes=shift;
  $mes->errmsg($mes->is_success()? 'Login OK' : 'Login failed') unless $mes->errmsg();
  return $mes->result_status();
 }
 
 sub extract_session
 {
- my ($class,$mes)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my $mes=shift;
  return { id => $mes->result() };
 }
 
@@ -85,25 +93,21 @@ sub extract_session
 
 sub logout
 {
- my ($class,$cm,$cltrid,$sd)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my ($cm,$cltrid,$sd)=@_;
  my $mes=$cm->();
  $mes->method('logout');
- $mes->params([$sd->{id}]);
+ $mes->params({session => $sd->{id}});
  return $mes;
 }
 
 sub parse_logout
 {
- my ($class,$mes)=@_;
+ shift if ($_[0] eq __PACKAGE__);
+ my $mes=shift;
  $mes->errmsg($mes->is_success()? 'Logout OK' : 'Logout failed') unless $mes->errmsg();
  return $mes->result_status();
 }
 
-sub transport_default
-{
- my ($self,$tname)=@_;
- return (defer => 1, has_login => 1, has_logout => 1);
-}
-
 ####################################################################################################
 1;
