@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OVH Web Services Message
 ##
-## Copyright (c) 2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,13 +10,14 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::OVH::WS::Message;
 
-use utf8;
 use strict;
-use warnings;
 
 use Carp;
 use Net::DRI::Protocol::ResultStatus;
@@ -24,6 +25,8 @@ use Net::DRI::Protocol::ResultStatus;
 use base qw(Class::Accessor::Chained::Fast Net::DRI::Protocol::Message);
 __PACKAGE__->mk_accessors(qw(version method params result errcode errmsg));
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -52,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,32 +71,21 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($class,$trid,$otype,$oaction)=@_;
+ my $class=shift;
  my $self={errcode => undef, errmsg => undef};
  bless($self,$class);
+ my ($trid,$otype,$oaction)=@_;
 
- $self->params([]); ## default
+ $self->params({}); ## default
  return $self;
 }
 
-sub as_string
-{
- my ($self)=@_;
- my @p=@{$self->params()};
- my @pr;
- foreach my $i (0..$#p)
- {
-  push @pr,sprintf 'PARAM%d=%s',$i+1,$p[$i];
- }
- return sprintf "METHOD=%s\n%s\n",$self->method(),join("\n",@pr);
-}
-
+sub as_string { return; }
 sub add_session
 {
  my ($self,$sd)=@_;
  my $rp=$self->params();
- unshift @$rp,$sd->{id};
- return;
+ $rp->{session}=$sd->{id};
 }
 
 sub parse
@@ -111,32 +103,31 @@ sub parse
   $self->errcode(100); ## probably success
   $self->errmsg('No status/msg given');
  }
- return;
 }
 
 ## See http://guides.ovh.com/ManagerV3Status and http://wikikillers.eu/index.php?title=Codes_d%27erreurs
 my %CODES=( 	201 => 2003,# parametre(s) manquant(s)
 		202 => 2005,# parametre(s) invalide(s)
 		203 => 2306,# parametres incompatibles
-		210 => 2306,# donnée inconnue
-		211 => 2306,# donnée deja existante
-		212 => 2308,# l'action n'a affectée aucune donnée
-		213 => 2306,# donnée en doublon
-		214 => 2308,# l'action a affectée trop de données
-		220 => 2304,# donnée en cours de traitement
+		210 => 2306,# donne inconnue
+		211 => 2306,# donne deja existante
+		212 => 2308,# l'action n'a affecte aucune donne
+		213 => 2306,# donne en doublon
+		214 => 2308,# l'action a affecte trop de donnes
+		220 => 2304,# donne en cours de traitement
 		230 => 2101,# fonction inactive
 		240 => 2304,# action en cours de traitement
 		241 => 2308,# action impossible
-		250 => 2101,# fonction non implémenté
-		251 => 2000,# fonction obsolète
+		250 => 2101,# fonction non implment
+		251 => 2000,# fonction obsolte
 		252 => 2308,# fonction innaccessible
 		260 => 2400,# erreur, pas d'info supplementaire
-		266 => 2400,# toutes les fonctions du merge ont échoué: pas de resultat
-		267 => 2400,# certaines fonctions ont échoués: l'action devra etre entreprise de nouveau plus tard
+		266 => 2400,# toutes les fonctions du merge ont chou: pas de resultat
+		267 => 2400,# certaines fonctions ont chous: l'action devra etre entreprise de nouveau plus tard
 		280 => 2400,# erreur interne
-		281 => 2400,# traitement échoué
+		281 => 2400,# traitement chou
 		299 => 2005,# parametres excedentaires
-		301 => 2200,# session expirée ## should trigger a new login
+		301 => 2200,# session expire ## should trigger a new login
 		302 => 2200,# session inexistante ## should trigger a new login
 		303 => 2200,# session corrompue ## should trigger a new login
 		304 => 2502,# trop de sessions actives ## should trigger a call to ClearNicSessions and a retry
@@ -145,21 +136,21 @@ my %CODES=( 	201 => 2003,# parametre(s) manquant(s)
 		401 => 2201,# pas de droit d'acces
 		402 => 2201,# droits insuffisants
 		403 => 2200,# session en lecture seule
-		451 => 2400,# quota dépassé
-		461 => 2400,# hacké
-		501 => 2400,# probleme connexion base de données
-		502 => 2400,# donnée erronée au sein du serveur
+		451 => 2400,# quota dpass
+		461 => 2400,# hack
+		501 => 2400,# probleme connexion base de donnes
+		502 => 2400,# donne errone au sein du serveur
 		503 => 2400,# probleme connexion
 		504 => 2400,# probleme connexion dns
 		505 => 2400,# probleme interne au serveur
 		506 => 2400,# parametre interne invalide
-		510 => 2308,# données introuvable
+		510 => 2308,# donnes introuvable
 		601 => 2400,# parametres mysql corrompus
 		701 => 2304,# domaine dans un etat incompatible
-		702 => 2307,# fonction non supportée par le domaine (ex:multidomain sur un gp)
-		703 => 2304,# objet dans un état incompatible
-		704 => 2305,# un processus bloquant interdit la création de l'objet
-		705 => 2002,# plus de données a traité.
+		702 => 2307,# fonction non supporte par le domaine (ex:multidomain sur un gp)
+		703 => 2304,# objet dans un tat incompatible
+		704 => 2305,# un processus bloquant interdit la cration de l'objet
+		705 => 2002,# plus de donnes a trait.
 		706 => 2400,# impossible d'obtenir le lock
 		777 => 2400,# pas de numero d'erreur donne
 	);
@@ -175,13 +166,26 @@ sub result_status
 
  if ($code >= 101 && $code <=199)
  {
-  carp('Got a "warning" error code, please report: '.$code.' '.$msg);
+  carp('Got a  warning  error code, please report: '.$code.' '.$msg);
   $ok=1;
  }
 
- my $eppcode=(defined $code && exists $CODES{$code})? $CODES{$code} : 'COMMAND_FAILED';
+ my $eppcode=(defined($code) && exists($CODES{$code}))? $CODES{$code} : 'GENERIC_ERROR';
  return Net::DRI::Protocol::ResultStatus->new('ovh_ws',$code,$ok? 'COMMAND_SUCCESSFUL' : $eppcode,$ok,$msg,'en');
 }
 
+####################################################################################################
+
+sub get_name_from_message
+{
+ my ($self)=@_;
+ my $c=$self->method();
+ my $rp=$self->params();
+
+ return 'domains' if ($c eq 'domainList');
+ return $rp->{domain} if ($c=~m/^domain/);
+ return 'session';
+}
+
 ####################################################################################################
 1;
