@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Whois commands for .LU (RFC3912)
 ##
-## Copyright (c) 2008,2009,2013,2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,24 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois::Domain::LU;
 
 use strict;
-use warnings;
 
 use Carp;
+use DateTime::Format::Strptime;
 use Net::DRI::Exception;
 use Net::DRI::Util;
 use Net::DRI::Protocol::EPP::Core::Status;
+use Net::DRI::Data::ContactSet;
+use Net::DRI::Data::Contact::LU;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,7 +57,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013,2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -75,8 +82,7 @@ sub info
  my ($po,$domain,$rd)=@_;
  my $mes=$po->message();
  Net::DRI::Exception->die(1,'protocol/whois',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
- $mes->command(lc $domain);
- return;
+ $mes->command(lc($domain));
 }
 
 sub info_parse
@@ -87,24 +93,23 @@ sub info_parse
 
  my $rr=$mes->response();
  my $rd=$mes->response_raw();
- my ($domain,$exist)=parse_domain($po,$rr,$rd,$rinfo);
+ my ($domain,$exist)=parse_domain($rr,$rd,$rinfo);
  $domain=lc($oname) unless defined($domain);
  $rinfo->{domain}->{$domain}->{exist}=$exist;
  $rinfo->{domain}->{$domain}->{action}='info';
 
  return unless $exist;
 
- parse_status($po,$domain,$rr,$rinfo);
- parse_ns($po,$domain,$rr,$rinfo);
- parse_dates($po,$domain,$rr,$rinfo);
- parse_contacts($po,$domain,$rr,$rinfo);
- parse_registrars($po,$domain,$rr,$rinfo);
- return;
+ parse_status($domain,$rr,$rinfo);
+ parse_ns($domain,$rr,$rinfo);
+ parse_dates($domain,$rr,$rinfo);
+ parse_contacts($domain,$rr,$rinfo);
+ parse_registrar($domain,$rr,$rinfo);
 }
 
 sub parse_domain
 {
- my ($po,$rr,$rd,$rinfo)=@_;
+ my ($rr,$rd,$rinfo)=@_;
  my ($dom,$e);
  if ($rd=~m/\n% WHOIS (\S+)\n% No such domain$/s)
  {
@@ -120,17 +125,16 @@ sub parse_domain
 
 sub parse_status
 {
- my ($po,$domain,$rr,$rinfo)=@_;
+ my ($domain,$rr,$rinfo)=@_;
  my @s=map { my $s=$_; $s=~s/ACTIVE/ok/; $s; } @{$rr->{'domaintype'}};
  carp('For '.$domain.' new status found, please report: '.join(' ',@s)) if (grep { $_ ne 'ok' } @s);
  $rinfo->{domain}->{$domain}->{status}=Net::DRI::Protocol::EPP::Core::Status->new(\@s) if @s;
- return;
 }
 
 sub parse_ns
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- my $h=$po->create_local_object('hosts');
+ my ($domain,$rr,$rinfo)=@_;
+ my $h=Net::DRI::Data::Hosts->new();
  foreach my $ns (grep { defined($_) && $_ } @{$rr->{'nserver'}})
  {
   if (my ($name,$ips)=($ns=~m/^(\S+) \[(\S+)\]$/))
@@ -143,25 +147,23 @@ sub parse_ns
   }
  }
  $rinfo->{domain}->{$domain}->{ns}=$h unless $h->is_empty();
- return;
 }
 
 sub parse_dates
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- my $strp=$po->build_strptime_parser(pattern => '%d/%m/%Y', time_zone => 'Europe/Luxembourg');
+ my ($domain,$rr,$rinfo)=@_;
+ my $strp=DateTime::Format::Strptime->new(pattern => '%d/%m/%Y', time_zone => 'Europe/Luxembourg');
  $rinfo->{domain}->{$domain}->{crDate}=$strp->parse_datetime($rr->{'registered'}->[0]);
- return;
 }
 
 sub parse_contacts
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- my $cs=$po->create_local_object('contactset');
+ my ($domain,$rr,$rinfo)=@_;
+ my $cs=Net::DRI::Data::ContactSet->new();
  my %t=('org' => 'registrant', 'adm' => 'admin', 'tec' => 'tech');
- foreach my $t (sort { $a cmp $b } keys %t)
+ foreach my $t (keys(%t))
  {
-  my $c=$po->create_local_object('contact');
+  my $c=Net::DRI::Data::Contact::LU->new();
   $c->type('contact');
   $c->name($rr->{$t.'-name'}->[0]) if (exists($rr->{$t.'-name'}) && $rr->{$t.'-name'}->[0]);
   $c->street($rr->{$t.'-address'}) if (exists($rr->{$t.'-address'}) && @{$rr->{$t.'-address'}});
@@ -178,17 +180,15 @@ sub parse_contacts
  $cs->get('registrant')->type($ot{$type});
 
  $rinfo->{domain}->{$domain}->{contact}=$cs;
- return;
 }
 
-sub parse_registrars
+sub parse_registrar
 {
- my ($po,$domain,$rr,$rinfo)=@_;
+ my ($domain,$rr,$rinfo)=@_;
  $rinfo->{domain}->{$domain}->{clName}=$rr->{'registrar-name'}->[0];
  $rinfo->{domain}->{$domain}->{clEmail}=$rr->{'registrar-email'}->[0];
  $rinfo->{domain}->{$domain}->{clWebsite}=$rr->{'registrar-url'}->[0];
  $rinfo->{domain}->{$domain}->{clCountry}=$rr->{'registrar-country'}->[0];
- return;
 }
 
 ####################################################################################################
