@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Whois commands for .NAME (RFC3912)
 ##
-## Copyright (c) 2007,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois::Domain::NAME;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
-use Net::DRI::Protocol::Whois::Domain::common;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -49,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -75,7 +78,6 @@ sub info
  my $mes=$po->message();
  Net::DRI::Exception->die(1,'protocol/whois',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
  $mes->command('domain '.lc($domain));
- return;
 }
 
 sub info_parse
@@ -86,20 +88,19 @@ sub info_parse
 
  my $rr=$mes->response();
  my $rd=$mes->response_raw();
- my ($domain,$exist)=parse_domain($po,$rr,$rd,$rinfo);
+ my ($domain,$exist)=parse_domain($rr,$rd,$rinfo);
  $domain=lc($oname) unless defined($domain);
  $rinfo->{domain}->{$domain}->{exist}=$exist;
  $rinfo->{domain}->{$domain}->{action}='info';
 
  return unless $exist;
 
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_status($po,$domain,$rr,$rinfo);
- return;
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_status($domain,$rr,$rinfo);
 }
 
 sub parse_domain
 {
- my ($po,$rr,$rd,$rinfo)=@_;
+ my ($rr,$rd,$rinfo)=@_;
  my ($dom,$e);
  if (exists($rr->{'Domain Name ID'}))
  {
